@@ -4,21 +4,29 @@ use strict;
 use warnings;
 use 5.008001;
 use Alien::Build::Plugin;
-use Module::Load ();
 
 # ABSTRACT: Plugin to extract links from HTML using Mojo::DOM or Mojo::DOM58
-our $VERSION = '1.94'; # VERSION
+our $VERSION = '1.98'; # VERSION
 
 
-sub _load ($)
+sub _load ($;$)
 {
-  eval { Module::Load::load($_[0]) };
-  $@ eq '' ? 1 : 0;
+  my($class, $version) = @_;
+  my $pm = "$class.pm";
+  $pm =~ s/::/\//g;
+  eval { require $pm };
+  return 0 if $@;
+  if(defined $version)
+  {
+    eval { $class->VERSION($version) };
+    return 0 if $@;
+  }
+  return 1;
 }
 
 has _class => sub {
   return 'Mojo::DOM58' if _load 'Mojo::DOM58';
-  return 'Mojo::DOM'   if _load 'Mojo::DOM' && _load 'Mojolicious' && eval { Mojolicious->VERSION('7.00') };
+  return 'Mojo::DOM'   if _load 'Mojo::DOM' && _load 'Mojolicious', 7.00;
   return 'Mojo::DOM58';
 };
 
@@ -95,7 +103,7 @@ Alien::Build::Plugin::Decode::Mojo - Plugin to extract links from HTML using Moj
 
 =head1 VERSION
 
-version 1.94
+version 1.98
 
 =head1 SYNOPSIS
 
@@ -189,7 +197,7 @@ Paul Evans (leonerd, PEVANS)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
