@@ -18,7 +18,7 @@ use Config;
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '1.89'; # VERSION
+our $VERSION = '1.98'; # VERSION
 
 
 our @aliens;
@@ -485,6 +485,7 @@ sub ffi_ok
     my $min = '0.12'; # the first CPAN release
     $min = '0.15' if $opt->{ignore_not_found};
     $min = '0.18' if $opt->{lang};
+    $min = '0.99' if defined $opt->{api} && $opt->{api} > 0;
     unless(eval { require FFI::Platypus; FFI::Platypus->VERSION($min) })
     {
       $ok = 0;
@@ -510,9 +511,15 @@ sub ffi_ok
   if($ok)
   {
     $ffi = FFI::Platypus->new(
-      lib              => [map { $_->dynamic_libs } @aliens],
-      ignore_not_found => $opt->{ignore_not_found},
-      lang             => $opt->{lang},
+      do {
+        my @args = (
+          lib              => [map { $_->dynamic_libs } @aliens],
+          ignore_not_found => $opt->{ignore_not_found},
+          lang             => $opt->{lang},
+        );
+        push @args, api => $opt->{api} if defined $opt->{api};
+        @args;
+      }
     );
     foreach my $symbol (@{ $opt->{symbols} || [] })
     {
@@ -647,7 +654,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 1.89
+version 1.98
 
 =head1 SYNOPSIS
 
@@ -927,6 +934,16 @@ not influence the C<symbols> key above.
 
 Set the language.  Used primarily for language specific native types.
 
+=item api
+
+Set the API.  C<api = 1> requires FFI::Platypus 0.99 or later.  This
+option was added with Test::Alien version 1.90, so your use line should
+include this version as a safeguard to make sure it works:
+
+ use Test::Alien 1.90;
+ ...
+ ffi_ok ...;
+
 =back
 
 As with L</xs_ok> above, you can use the C<with_subtest> keyword to specify
@@ -1042,7 +1059,7 @@ Paul Evans (leonerd, PEVANS)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
